/**
 * Der Dateneintrag in einem Binrbaum.
 * Diese Schnittstelle enthlt Methoden, mit denen die Eintrge
 * einem Baum sowohl graphisch veranschaulicht als auch
 * nichtgraphisch verwaltet werden knnen.
 * 
 * @author Bernd Gramlich 
 * @version 2012-12-14
 */
public interface Eintrag
{   
    /**
     * Zeichne den Eintrag an der "baumposition".
     * 
     * @param baumposition Zeichenkette aus "l" und "r", die beschreibt,
     *                     wie man von der Baumwurzel ab zum Eintrag kommt.
     */
    void zeichneAnBaumposition (String baumposition);

    /**
     * Mache den Eintrag graphisch unsichtbar.
     */
    void macheUnsichtbar ();
    
    /**
     * Gib an, ob dieser Eintrag kleiner als ein anderer Eintrag ist.
     * 
     * @return true, falls der Eintrag kleiner als "andererEintrag" ist.
     *         false, falls der Eintrag grer oder gleich
     *         "andererEintrag" ist oder falls die beiden Eintrge nicht
     *         vergleichbar sind.
     */
    boolean istKleinerAls (Eintrag andererEintrag);
    
    /**
     * Drucke den Eintrag auf die Konsole.
     */
    void druckeAufKonsole ();
    
    /**
     * Vergleiche den Eintrag mit dem Suchwort.
     * 
     * @param suchwort Der gesuchte Begriff.
     * @return eine negative Zahl, wenn der Eintrag alphabetisch vor dem Suchwort kommt.
     *         0, wenn der Eintrag mit dem Suchwort bereinstimmt.
     *         eine positive Zahl, wenn der Eintrag alphabetisch nach dem Suchwort kommt.
     */
    int vergleicheMit (String suchwort);
}
