import java.awt.Polygon;
import java.util.List;
import java.util.ArrayList;
import java.lang.Integer;

/**
 * Zeichnet ein Vieleck auf die Leinwand.
 * 
 * @author Bernd Gramlich
 * @version 2012.12.20
 */
public class Vieleck
{
    // Anzahl der Ecken.
    private int eckenzahl;
    
    // Koordinaten der Ecken als Integer 
    // (mssen vor dem Zeichnen in int umgewandelt werden).
    private List<Integer> eckeX;
    private List<Integer> eckeY;
    
    // Fllfarbe.
    private String farbe;
    
    // Sichtbarkeit.
    private boolean sichtbar;

    /**
     * Konstruktor der Klasse Vieleck.
     * Erzeugt eine unsichtbares, leeres Vieleck (noch ohne Eckpunkte) in Standardfarbe.
     */
    public Vieleck ()
    {
        eckenzahl     = 0;
        eckeX         = new ArrayList<Integer> ();
        eckeY         = new ArrayList<Integer> ();
        farbe         = "rot";
        sichtbar      = false;
    }
    
	/**
	 * Mache dieses Vieleck sichtbar.
	 */
	public void macheSichtbar ()
	{
		sichtbar = true;
		zeichne ();
	}

	/**
	 * Mache dieses Vieleck unsichtbar.
	 */
	public void macheUnsichtbar ()
	{
		loesche ();
		sichtbar = false;
	}
	
	/**
	 * Fge zum Vieleck einen Eckpunkt mit Koordinaten (x|y) hinzu.
	 */
	public void ergaenzeEcke (int x, int y)
	{
	    eckenzahl++;
	    eckeX.add (new Integer (x));
	    eckeY.add (new Integer (y));
	    zeichne ();
	}
		
	/**
	 * Lsche den Eckpunkt mit der Nummer k.
	 */
	public boolean loescheEcke (int k)
	{
	    if (k >= 0 && k < eckenzahl)
	    {
	        eckenzahl--;
	        eckeX.remove (k);
	        eckeY.remove (k);
	        zeichne ();
	        return true;
	    }
	    else
	    {
	        return false;
	    }
	}
	
	/**
	 * Lsche alle Eckpunkte.
	 */
	public void loescheAlleEcken ()
	{
	    eckenzahl = 0;
	    eckeX.clear ();
	    eckeY.clear ();
	    zeichne ();
	}
		
	/**
	 * Verschiebe den Eckpunkt mit der Nummer k um den Vektor (dx|dy).
	 */
	public boolean verschiebeEcke (int k, int dx, int dy)
	{
	    if (k >= 0 && k < eckenzahl)
	    {
	        eckeX.set (k, new Integer (eckeX.get (k).intValue () + dx));
		    eckeY.set (k, new Integer (eckeY.get (k).intValue () + dy));
	        zeichne ();
	        return true;
	    }
	    else
	    {
	        return false;
	    }
	}
		
	/**
	 * Gib dem Eckpunkt mit der Nummer k die neuen Koordinaten (x|y).
	 */
	public boolean aendereEcke (int k, int x, int y)
	{
	    if (k >= 0 && k < eckenzahl)
	    {
	        eckeX.set (k, new Integer (x));
		    eckeY.set (k, new Integer (y));
	        zeichne ();
	        return true;
	    }
	    else
	    {
	        return false;
	    }
	}
		
	/**
	 * ndere die Farbe dieses Vielecks in 'neueFarbe'. Gltige Angaben sind
	 * "rot", "gelb", "blau", "grn", "lila", "schwarz", "wei", "grau"
	 * "orange", "pink" und "trkis".
	 */
	public void setzeFarbe (String neueFarbe)
	{
		farbe = neueFarbe;
		zeichne ();
	}
	
	/**
	 * Verschiebe dieses Vieleck um den Vektor (dx, dy).
	 */
	public void verschiebe (int dx, int dy)
	{
		for (int i = 0; i < eckenzahl; i++)
		{
		    eckeX.set (i, new Integer (eckeX.get (i).intValue () + dx));
		    eckeY.set (i, new Integer (eckeY.get (i).intValue () + dy));
		}
		
		zeichne ();
	}
	
	/**
	 * Zeichne dieses Vieleck auf die Leinwand.
	 */
	private void zeichne ()
	{
		if (sichtbar)
		{
			Leinwand leinwand = Leinwand.gibLeinwand ();
			int[] eckpunktX;
			int[] eckpunktY;
			
			eckpunktX = new int[eckenzahl];
			eckpunktY = new int[eckenzahl];
			
			for (int i = 0; i < eckenzahl; i++)
			{
			    eckpunktX[i] = eckeX.get (i).intValue ();
			    eckpunktY[i] = eckeY.get (i).intValue ();
			}
			
			leinwand.zeichne (this, farbe, new Polygon (eckpunktX, eckpunktY, eckenzahl));
			leinwand.warte (10);
		}
	}

	/**
	 * Lsche dieses Vieleck von der Leinwand.
	 */
	private void loesche ()
	{
		if (sichtbar) {
			Leinwand leinwand = Leinwand.gibLeinwand ();
			leinwand.entferne (this);
		}
	}

	/**
	 * Nenne die Farbe des Vielecks.
	 */
	public String gibFarbe ()
	{
		return farbe;
	}
}
